@@ -1,8 +1,12 @@
-from django.core.cache import cache
+from django.core.cache import get_cache
 from django.utils.datastructures import SortedDict
 
 import nexus
 
+from nexus_memcache import conf
+
+cache = get_cache(conf.BACKEND)._cache
+
 class MemcacheModule(nexus.NexusModule):
     home_url = 'index'
     name = 'memcache'
@@ -21,7 +25,7 @@ class MemcacheModule(nexus.NexusModule):
     
     def render_on_dashboard(self, request):
         try:
-            cache_stats = cache._cache.get_stats()
+            cache_stats = cache.get_stats()
         except AttributeError:
             cache_stats = []
         
@@ -49,7 +53,7 @@ class MemcacheModule(nexus.NexusModule):
     
     def index(self, request):
         try:
-            cache_stats = ((k, SortedDict(sorted(v.iteritems(), key=lambda x: x[0]))) for k, v in cache._cache.get_stats())
+            cache_stats = ((k, SortedDict(sorted(v.iteritems(), key=lambda x: x[0]))) for k, v in cache.get_stats())
         except AttributeError:
             cache_stats = []
         
